# ------------------------------------------------------------------------------
# Copyright IBM Corp. 2018
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ------------------------------------------------------------------------------

from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='csvtoparquet',
    version='0.1.4',
    setup_requires=['pytest-runner'],
    tests_require=['pytest'],
    install_requires=['pandas','pyarrow','ibm-cos-sdk','simplejson'],
    author='IBM',
    author_email='abdullah.alger@ibm.com',
    license='Apache 2.0',
    long_description=long_description,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Intended Audience :: Developers',
        'Natural Language :: English'
    ],
    keywords='cloud csv parquet object_storage IBM',
    packages=['csvtoparquet'],
    entry_points={
        'console_scripts': ['csvtoparquet = csvtoparquet.converter:main']
    }
)